pecos.tools.logic\_circuit\_speed
=================================

.. automodule:: pecos.tools.logic_circuit_speed

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      generate_circuits
      get_qubits
      random_circuit_speed
   
   

   
   
   

   
   
   



